==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_val-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="val-ES" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Crea un full de càlcul</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Crea un full de càlcul nouj</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Alinea a la part inferior</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Alineació a la part inferior del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Alinea al centre</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Alineació al centre del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Alinea a l'esquerra</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Alineació a l'equerra del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Alinea a la dreta</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Alineació a la dreta del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Alinea a la part superior</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Alineació a la part superior del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Alinea al centre verticalment</translation>
    </message>
    <message>
      <source>Center-align contents vertically of selected cells</source>
      <translation>Alineació al centre verticalment de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Exporta el full de càlcul</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Exporta el full de càlcul a CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importa el full de càlcul</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importa el fitxer CSV a un full de càlcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Fusiona les cel·les</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Fusiona les cel·les seleccionades en el full de càlcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Estableix l'àlies</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Estableix l'àlies per a les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Divideix la cel·la</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Divideix les cel·les fusionades anteriorment en el full de càlcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Text en negreta</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Estableix el text en negreta en les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Text en cursiva</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Estableix el text en cursiva en les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Text subratllat</translation>
    </message>
    <message>
      <source>Set underline text in selected cells</source>
      <translation>Estableix el text subratllat en les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom</source>
      <translation>Personalitzat</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Propietats de cel·la</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Color</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Text</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Fons</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Alineació</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Esquerra</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Center</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Dreta</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Planta</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Inferior</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>E&amp;stil</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Negreta</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Cursiva</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Subratllat</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Unitat de mesura</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Cadena d'unitats</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>À&amp;lies</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Àlies per a aquesta cel·la</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Tot (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importa el fitxer</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Exporta el fitxer</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Contingut de la cel·la</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Mostra el full de càlcul</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation type="unfinished">Set cell(s) foreground color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) foreground color</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation type="unfinished">Set cell(s) background color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) background color</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Negre</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Blanc</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Roig</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Roig fosc</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Verd</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Verd fosc</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Blau</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Blau fosc</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Cian</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Cian fosc</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Magenta fosc</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Groc</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Groc fosc</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Gris</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Gris fosc</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Gris clar</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Personalitzat</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Forma</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Contingut</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Sense nom</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Insereix files</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Suprimeix files</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Insereix columnes</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Suprimeix columnes</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Propietats...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_val-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="val-ES" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Crea un full de càlcul</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Crea un full de càlcul nouj</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Alinea a la part inferior</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Alineació a la part inferior del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Alinea al centre</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Alineació al centre del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Alinea a l'esquerra</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Alineació a l'equerra del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Alinea a la dreta</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Alineació a la dreta del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Alinea a la part superior</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Alineació a la part superior del contingut de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Alinea al centre verticalment</translation>
    </message>
    <message>
      <source>Center-align contents vertically of selected cells</source>
      <translation>Alineació al centre verticalment de les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Exporta el full de càlcul</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Exporta el full de càlcul a CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importa el full de càlcul</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importa el fitxer CSV a un full de càlcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Fusiona les cel·les</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Fusiona les cel·les seleccionades en el full de càlcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Estableix l'àlies</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Estableix l'àlies per a les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Divideix la cel·la</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Divideix les cel·les fusionades anteriorment en el full de càlcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Text en negreta</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Estableix el text en negreta en les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Text en cursiva</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Estableix el text en cursiva en les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Text subratllat</translation>
    </message>
    <message>
      <source>Set underline text in selected cells</source>
      <translation>Estableix el text subratllat en les cel·les seleccionades</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom</source>
      <translation>Personalitzat</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Propietats de cel·la</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Color</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Text</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Fons</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Alineació</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Esquerra</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Centre</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Dreta</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Planta</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Inferior</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>E&amp;stil</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Negreta</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Cursiva</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Subratllat</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Unitat de mesura</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Cadena d'unitats</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>À&amp;lies</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Àlies per a aquesta cel·la</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Tot (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importa el fitxer</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Exporta el fitxer</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Contingut de la cel·la</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Mostra el full de càlcul</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Estableix el color de primer pla de la cel·la(es)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Estableix el color de primer pla de la cel·la(es) del full de càlcul</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Estableix el color de fons de la cel·la(es)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Estableix el color de fons de la cel·la(es) del full de càlcul</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Negre</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Blanc</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Roig</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Roig fosc</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Verd</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Verd fosc</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Blau</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Blau fosc</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Cian</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Cian fosc</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Magenta fosc</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Groc</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Groc fosc</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Gris</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Gris fosc</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Gris clar</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Personalitzat</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Forma</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Contingut</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Sense nom</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Insereix files</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Suprimeix files</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Insereix columnes</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Suprimeix columnes</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Propietats...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Full de càlcul</translation>
    </message>
  </context>
</TS>
